=== modified file 'NEWS'
--- NEWS	2005-10-11 04:13:47 +0000
+++ NEWS	2005-10-12 11:15:06 +0000
@@ -1,3 +1,17 @@
+bzr 0.1.1 2005-10-12
+
+  BUG FIXES:
+
+    * Fix problem in pulling over http from machines that do not 
+      allow directories to be listed.
+
+    * Avoid harmless warning about invalid hash cache after 
+      upgrading branch format.
+
+  PERFORMANCE: 
+  
+    * Avoid some unnecessary http operations in branch and pull.
+
 bzr 0.1 2005-10-11
 
   NOTES:

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2005-10-11 04:13:47 +0000
+++ bzrlib/__init__.py	2005-10-12 11:15:23 +0000
@@ -39,7 +39,7 @@
 del locale
 
 __copyright__ = "Copyright 2005 Canonical Development Ltd."
-__version__ = '0.1'
+__version__ = '0.1.1'
 
 
 def get_bzr_revision():

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-11 03:27:29 +0000
+++ bzrlib/branch.py	2005-10-12 11:01:25 +0000
@@ -91,27 +91,6 @@
     return os.sep.join(s)
         
 
-def find_branch_root(t):
-    """Find the branch root enclosing the transport's base.
-
-    t is a Transport object.
-
-    It is not necessary that the base of t exists.
-
-    Basically we keep looking up until we find the control directory or
-    run into the root.  If there isn't one, raises NotBranchError.
-    """
-    orig_base = t.base
-    while True:
-        if t.has(bzrlib.BZRDIR):
-            return t
-        new_t = t.clone('..')
-        if new_t.base == t.base:
-            # reached the root, whatever that may be
-            raise NotBranchError('%s is not in a branch' % orig_base)
-        t = new_t
-
-
 ######################################################################
 # branch objects
 
@@ -145,10 +124,21 @@
         """Open an existing branch which contains url.
         
         This probes for a branch at url, and searches upwards from there.
+
+        Basically we keep looking up until we find the control directory or
+        run into the root.  If there isn't one, raises NotBranchError.
         """
         t = get_transport(url)
-        t = find_branch_root(t)
-        return _Branch(t)
+        while True:
+            try:
+                return _Branch(t)
+            except NotBranchError:
+                pass
+            new_t = t.clone('..')
+            if new_t.base == t.base:
+                # reached the root, whatever that may be
+                raise NotBranchError('%s is not in a branch' % url)
+            t = new_t
 
     @staticmethod
     def initialize(base):

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-10-13 03:00:57 +0000
+++ bzrlib/builtins.py	2005-10-13 03:46:45 +0000
@@ -388,20 +388,21 @@
         import errno
         from shutil import rmtree
         cache_root = tempfile.mkdtemp()
-        try:
-            if revision is None:
-                revision = [None]
-            elif len(revision) > 1:
-                raise BzrCommandError(
-                    'bzr branch --revision takes exactly 1 revision value')
-            try:
-                br_from = Branch.open(from_location)
-            except OSError, e:
-                if e.errno == errno.ENOENT:
-                    raise BzrCommandError('Source location "%s" does not'
-                                          ' exist.' % to_location)
-                else:
-                    raise
+        if revision is None:
+            revision = [None]
+        elif len(revision) > 1:
+            raise BzrCommandError(
+                'bzr branch --revision takes exactly 1 revision value')
+        try:
+            br_from = Branch.open(from_location)
+        except OSError, e:
+            if e.errno == errno.ENOENT:
+                raise BzrCommandError('Source location "%s" does not'
+                                      ' exist.' % to_location)
+            else:
+                raise
+        br_from.lock_read()
+        try:
             br_from.setup_caching(cache_root)
             if basis is not None:
                 basis_branch = Branch.open_containing(basis)
@@ -433,6 +434,7 @@
             except bzrlib.errors.UnlistableBranch:
                 msg = "The branch %s cannot be used as a --basis"
         finally:
+            br_from.unlock()
             rmtree(cache_root)
 
 
@@ -461,7 +463,6 @@
     
     def run(self, branch=None):
         import info
-
         b = Branch.open_containing(branch)
         info.show_info(b)
 

=== modified file 'bzrlib/hashcache.py'
--- bzrlib/hashcache.py	2005-09-30 02:54:51 +0000
+++ bzrlib/hashcache.py	2005-10-12 10:44:57 +0000
@@ -101,13 +101,11 @@
         self.update_count = 0
         self._cache = {}
 
-
     def cache_file_name(self):
+        # FIXME: duplicate path logic here, this should be 
+        # something like 'branch.controlfile'.
         return os.sep.join([self.basedir, '.bzr', 'stat-cache'])
 
-
-
-
     def clear(self):
         """Discard all cached information.
 

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2005-10-04 04:37:29 +0000
+++ bzrlib/transport/local.py	2005-10-12 11:01:25 +0000
@@ -74,8 +74,8 @@
             path = self.abspath(relpath)
             return open(path, 'rb')
         except IOError,e:
-            if e.errno == errno.ENOENT:
-                raise NoSuchFile('File %r does not exist' % path, orig_error=e)
+            if e.errno in (errno.ENOENT, errno.ENOTDIR):
+                raise NoSuchFile('File or directory %r does not exist' % path, orig_error=e)
             raise LocalTransportError(orig_error=e)
 
     def get_partial(self, relpath, start, length=None):

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2005-10-09 23:42:12 +0000
+++ bzrlib/upgrade.py	2005-10-12 10:44:57 +0000
@@ -87,6 +87,7 @@
 
 from bzrlib.branch import Branch, find_branch
 from bzrlib.branch import BZR_BRANCH_FORMAT_5, BZR_BRANCH_FORMAT_6
+import bzrlib.hashcache as hashcache
 from bzrlib.revfile import Revfile
 from bzrlib.weave import Weave
 from bzrlib.weavefile import read_weave, write_weave
@@ -122,6 +123,9 @@
             note('starting upgrade from format 5 to 6')
             self._convert_to_prefixed()
             self._open_branch()
+        cache = hashcache.HashCache(os.path.abspath(self.base))
+        cache.clear()
+        cache.write()
         note("finished")
 
 

